# Changelog

All notable changes to this project will be documented in this file.

<!-- insertion marker -->
## [0.1.10](https://github.com/siciarek/lgca/releases/tag/0.1.10) - 2024-12-25

<small>[Compare with 0.1.9](https://github.com/siciarek/lgca/compare/0.1.9...0.1.10)</small>

### Bug Fixes

- some invalid rules for fhp_iii collisions validated agains the Buick PHD lookup table, new shapes line horiz and vert ([21ba6a1](https://github.com/siciarek/lgca/commit/21ba6a172f0165aafa1daa47b313eead438bcd5e) by Jacek Siciarek).
- some invalid rules for fhp_iii collisions validated agains the Buick PHD lookup table ([11dd717](https://github.com/siciarek/lgca/commit/11dd717885a13469a77d6a9ec5e781c6f1478f66) by Jacek Siciarek).
- update tests ([0c27554](https://github.com/siciarek/lgca/commit/0c2755471991233baa171b670af9e9aebf92ab83) by Jacek Siciarek).
- refactor the entrypoint ([13f1af6](https://github.com/siciarek/lgca/commit/13f1af6f8e1f2924854e707efff78426bb2f0ed8) by Jacek Siciarek).
- improve code coverage ([f27a57b](https://github.com/siciarek/lgca/commit/f27a57bf1c6aa88b0a5d99f1577c1eee478ae0e9) by Jacek Siciarek).

## [0.1.9](https://github.com/siciarek/lgca/releases/tag/0.1.9) - 2024-12-23

<small>[Compare with 0.1.8](https://github.com/siciarek/lgca/compare/0.1.8...0.1.9)</small>

## [0.1.8](https://github.com/siciarek/lgca/releases/tag/0.1.8) - 2024-12-23

<small>[Compare with 0.1.7](https://github.com/siciarek/lgca/compare/0.1.7...0.1.8)</small>

## [0.1.7](https://github.com/siciarek/lgca/releases/tag/0.1.7) - 2024-12-23

<small>[Compare with 0.1.6](https://github.com/siciarek/lgca/compare/0.1.6...0.1.7)</small>

### Bug Fixes

- lint notifications ([d506eec](https://github.com/siciarek/lgca/commit/d506eec89c8b8af11d4fdc1b9eb57478959937ff) by Jacek Siciarek).

## [0.1.6](https://github.com/siciarek/lgca/releases/tag/0.1.6) - 2024-12-22

<small>[Compare with 0.1.5](https://github.com/siciarek/lgca/compare/0.1.5...0.1.6)</small>

## [0.1.5](https://github.com/siciarek/lgca/releases/tag/0.1.5) - 2024-12-22

<small>[Compare with 0.1.4](https://github.com/siciarek/lgca/compare/0.1.4...0.1.5)</small>

## [0.1.4](https://github.com/siciarek/lgca/releases/tag/0.1.4) - 2024-12-22

<small>[Compare with 0.1.3](https://github.com/siciarek/lgca/compare/0.1.3...0.1.4)</small>

## [0.1.3](https://github.com/siciarek/lgca/releases/tag/0.1.3) - 2024-12-22

<small>[Compare with 0.1.2](https://github.com/siciarek/lgca/compare/0.1.2...0.1.3)</small>

### Bug Fixes

- improve code coverage in tests ([5362da1](https://github.com/siciarek/lgca/commit/5362da11b25ffeb5927cd224118b37d544222e39) by Jacek Siciarek).

## [0.1.2](https://github.com/siciarek/lgca/releases/tag/0.1.2) - 2024-12-22

<small>[Compare with 0.1.1](https://github.com/siciarek/lgca/compare/0.1.1...0.1.2)</small>

## [0.1.1](https://github.com/siciarek/lgca/releases/tag/0.1.1) - 2024-12-22

<small>[Compare with 0.1.0](https://github.com/siciarek/lgca/compare/0.1.0...0.1.1)</small>

## [0.1.0](https://github.com/siciarek/lgca/releases/tag/0.1.0) - 2024-12-22

<small>[Compare with first commit](https://github.com/siciarek/lgca/compare/dc97d553495089fbe14ea836e2008177ec851658...0.1.0)</small>

### Bug Fixes

- refactor all the files according to lint ([9550ef4](https://github.com/siciarek/lgca/commit/9550ef412cf72099f2943b2142863f19d22562a3) by Jacek Siciarek).
